SpecOp

Enum SpecOp 

pub enum SpecOp {
Show 86 variants Eq, And, Or, Not, Imp, Add, Sub, Mul, Lt, Lte, Gt, Gte, BVNot, BVAnd, BVOr, BVXor, BVNeg, BVAdd, BVSub, BVMul, BVUdiv, BVUrem, BVSdiv, BVSrem, BVShl, BVLshr, BVAshr, BVUle, BVUlt, BVUgt, BVUge, BVSlt, BVSle, BVSgt, BVSge, BVSaddo, Rotr, Rotl, Extract, ZeroExt, SignExt, Concat, Replicate, FPEq, FPNe, FPLt, FPGt, FPLe, FPGe, FPPositiveInfinity, FPNegativeInfinity, FPPositiveZero, FPNegativeZero, FPNaN, FPAdd, FPSub, FPMul, FPDiv, FPMin, FPMax, FPNeg, FPCeil, FPFloor, FPSqrt, FPTrunc, FPNearest, FPIsZero, FPIsInfinite, FPIsNaN, FPIsNegative, FPIsPositive, Popcnt, Clz, Cls, Rev, ConvTo, Int2BV, BV2Nat, ToFP, ToFPUnsigned, ToFPFromFP, FPToUBV, FPToSBV, WidthOf, If, Switch,
}
An operation used to specify term semantics, similar to SMT-LIB syntax.

Variants



Eq



And



Or



Not



Imp



Add



Sub



Mul



Lt



Lte



Gt



Gte



BVNot



BVAnd



BVOr



BVXor



BVNeg



BVAdd



BVSub



BVMul



BVUdiv



BVUrem



BVSdiv



BVSrem



BVShl



BVLshr



BVAshr



BVUle



BVUlt



BVUgt



BVUge



BVSlt



BVSle



BVSgt



BVSge



BVSaddo



Rotr



Rotl



Extract



ZeroExt



SignExt



Concat



Replicate



FPEq



FPNe



FPLt



FPGt



FPLe



FPGe



FPPositiveInfinity



FPNegativeInfinity



FPPositiveZero



FPNegativeZero



FPNaN



FPAdd



FPSub



FPMul



FPDiv



FPMin



FPMax



FPNeg



FPCeil



FPFloor



FPSqrt



FPTrunc



FPNearest



FPIsZero



FPIsInfinite



FPIsNaN



FPIsNegative



FPIsPositive



Popcnt



Clz



Cls



Rev



ConvTo



Int2BV



BV2Nat



ToFP



ToFPUnsigned



ToFPFromFP



FPToUBV



FPToSBV



WidthOf



If



Switch