pub struct State {
pub name: Ident,
pub ty: ModelType,
pub default: SpecExpr,
pub pos: Pos,
}Expand description
Declare an element of global state accessible by verification specs.
Fields
name: IdentName of the state element.
ty: ModelTypeType of the state element.
default: SpecExprDefault specification, applied if the state is not modified.
pos: PosTrait Implementations
impl Eq for State
impl StructuralPartialEq for State